@@ -7,25 +7,25 @@ DOUBLE PRECISION sumx,sumx2,sumy,sumy2,sumxy,z,a,b
 DO i=1, p {
   np=0
   DO k=1, n {
-    if(xx(k,i)<1e30) np=np+1
+    if(xx(k,i) < 1d49) np = np + 1
   }
-  npair(i,i)=np
+  npair(i,i) = np
 
-  DO j=(i+1),p {
+  DO j=(i+1), p {
     m=0
     if(itype==1) {
       sumx=0d0; sumy=0d0; sumx2=0d0; sumy2=0d0; sumxy=0d0
     }
-    DO k=1,n {
+    DO k=1, n {
       xk=xx(k,i)
       yk=xx(k,j)
-      if(xk<1e30 & yk<1e30) {
-        m=m+1
+      if(xk < 1d49 & yk < 1d49) {
+        m=m + 1
 	if(itype==1) {
 	  a=xk; b=yk
-	  sumx=sumx+a
+	  sumx =sumx+a
 	  sumx2=sumx2+a*a
-	  sumy=sumy+b
+	  sumy =sumy+b
 	  sumy2=sumy2+b*b
 	  sumxy=sumxy+a*b
 	} else {
@@ -34,14 +34,14 @@ DO i=1, p {
 	}
       }
     }
-    npair(i,j)=m
-    if(m>1) {
+    npair(i,j) = m
+    if(m > 1) {
       if(itype==1) {
 	z=m
 	d=(sumxy-sumx*sumy/z)/dsqrt((sumx2-sumx*sumx/z)*(sumy2-sumy*sumy/z))
       } else CALL docorr(x, y, m, d, rx, ry, work, iwork)
       dmat(i,j)=d
-    } else dmat(i,j)=1e30
+    } else dmat(i,j)=1d50
   }
 }
 DO i=1,p {
@@ -64,9 +64,9 @@ END
 	DO i=1,n {
 	  a=rx(i)
 	  b=ry(i)
-	  sumx=sumx+a
+	  sumx =sumx+a
 	  sumx2=sumx2+a*a
-	  sumy=sumy+b
+	  sumy =sumy+b
 	  sumy2=sumy2+b*b
 	  sumxy=sumxy+a*b
 	}
